@@ -13,6 +13,12 @@
 #  SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 
 from raylib import rl, ffi
+from raylib.colors import *
+try:
+    from raylib.defines import *
+except AttributeError:
+    print("sorry deprecated enums dont work on dynamic version")
+
 
 from inspect import ismethod,getmembers,isbuiltin
 import inflection
@@ -24,32 +30,7 @@ current_module = __import__(__name__)
 def pointer(self, struct):
     return ffi.addressof(struct)
 
-LIGHTGRAY  =( 200, 200, 200, 255 )
-GRAY       =( 130, 130, 130, 255 )
-DARKGRAY   =( 80, 80, 80, 255 )
-YELLOW     =( 253, 249, 0, 255 )
-GOLD       =( 255, 203, 0, 255 )
-ORANGE     =( 255, 161, 0, 255 )
-PINK       =( 255, 109, 194, 255 )
-RED        =( 230, 41, 55, 255 )
-MAROON     =( 190, 33, 55, 255 )
-GREEN      =( 0, 228, 48, 255 )
-LIME       =( 0, 158, 47, 255 )
-DARKGREEN  =( 0, 117, 44, 255 )
-SKYBLUE    =( 102, 191, 255, 255 )
-BLUE       =( 0, 121, 241, 255 )
-DARKBLUE   =( 0, 82, 172, 255 )
-PURPLE     =( 200, 122, 255, 255 )
-VIOLET     =( 135, 60, 190, 255 )
-DARKPURPLE =( 112, 31, 126, 255 )
-BEIGE      =( 211, 176, 131, 255 )
-BROWN      =( 127, 106, 79, 255 )
-DARKBROWN  =( 76, 63, 47, 255 )
-WHITE      =( 255, 255, 255, 255 )
-BLACK      =( 0, 0, 0, 255 )
-BLANK      =( 0, 0, 0, 0 )
-MAGENTA    =( 255, 0, 255, 255 )
-RAYWHITE   =( 245, 245, 245, 255 )
+
 
 
 # I'm concerned that we are doing a lot of string comparisons on every function call to detect types.
@@ -75,8 +56,12 @@ def makefunc(a):
                     arg = ffi.new("int *", arg)
                 elif type(arg) is float:
                     arg = ffi.new("float *", arg)
-                elif str(type(arg)) == "<class '_cffi_backend.__CDataOwn'>" and "*" not in str(arg):
+                elif str(type(arg)) == "<class '_cffi_backend.__CDataOwn'>" and "*" not in str(arg): #CPython
                     arg = ffi.addressof(arg)
+                elif str(type(arg)) == "<class '_cffi_backend._CDataBase'>" and "*" not in str(arg): #Pypy
+                    arg = ffi.addressof(arg)
+                elif arg is None:
+                    arg = ffi.NULL
             modified_args.append(arg)
         result = a(*modified_args)
         if result is None:
@@ -116,3 +101,5 @@ for struct in ffi.list_types()[0]:
     f = makeStructHelper(struct)
     setattr(current_module, struct, f)
 
+# overwrite ffi enums with our own
+from raylib.enums import *
